@@ -10,17 +10,15 @@ import warnings
 import time
 from datetime import timedelta
 import tensorflow as tf
-import tensorflow.keras as ks
 
 import orcanet.backend as backend
 from orcanet.utilities.visualization import update_summary_plot
 from orcanet.in_out import IOHandler
 from orcanet.history import HistoryHandler
-from orcanet.utilities.nn_utilities import load_zero_center_data, get_auto_label_modifier
-from orcanet.utilities.misc import from_register
-import orcanet.utilities.losses
-import orcanet.utilities.sample_modifiers as sample_modifiers
-import orcanet.logging as olog
+from orcanet.utilities.nn_utilities import load_zero_center_data
+import orcanet.lib as lib
+import orcanet.logging as logging
+import orcanet.misc
 import medgeconv
 
 
@@ -42,7 +40,8 @@ class Organizer:
     def __init__(self, output_folder,
                  list_file=None,
                  config_file=None,
-                 tf_log_level=None):
+                 tf_log_level=None,
+                 discover_tomls=True):
         """
         Set the attributes of the Configuration object.
 
@@ -59,20 +58,30 @@ class Organizer:
             Path to a toml list file with pathes to all the h5 files that should
             be used for training and validation.
             Will be used to extract samples and labels.
+            Default: Look for a file called 'list.toml' in the given output_folder.
         config_file : str, optional
             Path to a toml config file with settings that are used instead of
             the default ones.
+            Default: Look for a file called 'config.toml' in the given output_folder.
         tf_log_level : int/str
             Sets the TensorFlow CPP_MIN_LOG_LEVEL environment variable.
             0 = all messages are logged (default behavior).
             1 = INFO messages are not printed.
             2 = INFO and WARNING messages are not printed.
             3 = INFO, WARNING, and ERROR messages are not printed.
+        discover_tomls : bool
+            If False, do not try to look for toml files in the given
+            output_folder if list_file or config_file is None [Default: True].
 
         """
         if tf_log_level is not None:
             os.environ['TF_CPP_MIN_LOG_LEVEL'] = str(tf_log_level)
 
+        if discover_tomls and list_file is None:
+            list_file = orcanet.misc.find_file(output_folder, "list.toml")
+        if discover_tomls and config_file is None:
+            config_file = orcanet.misc.find_file(output_folder, "config.toml")
+
         self.cfg = Configuration(output_folder, list_file, config_file)
         self.io = IOHandler(self.cfg)
         self.history = HistoryHandler(output_folder)
@@ -194,7 +203,7 @@ class Organizer:
 
         if latest_epoch is None:
             self.io.check_connections(model)
-            olog.log_start_training(self)
+            logging.log_start_training(self)
 
         model_path = self.io.get_model_path(*next_epoch)
         model_path_local = self.io.get_model_path(*next_epoch, local=True)
@@ -203,10 +212,10 @@ class Organizer:
                 "Can not train model in epoch {} file {}, this model has "
                 "already been saved!".format(*next_epoch))
 
-        smry_logger = olog.SummaryLogger(self, model)
+        smry_logger = logging.SummaryLogger(self, model)
 
         if self.cfg.learning_rate is not None:
-            ks.backend.set_value(
+            tf.keras.backend.set_value(
                 model.optimizer.lr, self.io.get_learning_rate(next_epoch)
             )
 
@@ -217,7 +226,7 @@ class Organizer:
         self.io.print_log(line)
         self.io.print_log("-" * len(line))
         self.io.print_log("Learning rate is at {}".format(
-            ks.backend.get_value(model.optimizer.lr)))
+            tf.keras.backend.get_value(model.optimizer.lr)))
         self.io.print_log('Inputs and files:')
         for input_name, input_file in files_dict.items():
             self.io.print_log("   {}: \t{}".format(input_name,
@@ -231,7 +240,7 @@ class Organizer:
         model.save(model_path)
         smry_logger.write_line(
             next_epoch_float,
-            ks.backend.get_value(model.optimizer.lr),
+            tf.keras.backend.get_value(model.optimizer.lr),
             history_train=history,
         )
 
@@ -276,9 +285,9 @@ class Organizer:
         self._set_up(model, logging=True)
 
         epoch_float = self.io.get_epoch_float(*latest_epoch)
-        smry_logger = olog.SummaryLogger(self, model)
+        smry_logger = logging.SummaryLogger(self, model)
 
-        olog.log_start_validation(self)
+        logging.log_start_validation(self)
 
         start_time = time.time()
         history = backend.validate_model(self, model)
@@ -297,23 +306,21 @@ class Organizer:
 
         return history
 
-    def predict(self, epoch=None, fileno=None, concatenate=False, samples=None):
+    def predict(self, epoch=None, fileno=None, samples=None):
         """
         Make a prediction if it does not exist yet, and return its filepath.
 
         Load the model with the lowest validation loss, let it predict on
         all samples of the validation set
         in the toml list, and save this prediction together with all the
-        y_values as a h5 file in the predictions subfolder.
+        y_values as h5 file(s) in the predictions subfolder.
 
         Parameters
         ----------
         epoch : int, optional
-            Epoch of a model to load.
+            Epoch of a model to load. Default: lowest val loss.
         fileno : int, optional
-            File number of a model to load.
-        concatenate : bool
-            Whether the prediction files should also be concatenated.
+            File number of a model to load. Default: lowest val loss.
         samples : int, optional
             Don't use the full validation files, but just the given number
             of samples.
@@ -321,9 +328,7 @@ class Organizer:
         Returns
         -------
         pred_filename : List
-            List to the paths of all created prediction files.
-            If concatenate = True, the list always only contains the
-            path to the concatenated prediction file.
+            List to the paths of all the prediction files.
 
         """
         if fileno is None and epoch is None:
@@ -333,8 +338,7 @@ class Organizer:
             raise ValueError(
                 "Either both or none of epoch and fileno must be None")
 
-        is_pred_done = self._check_if_pred_already_done(epoch, fileno)
-        if is_pred_done:
+        if self._check_if_pred_already_done(epoch, fileno):
             print("Prediction has already been done.")
             pred_filepaths = self.io.get_pred_files_list(epoch, fileno)
 
@@ -354,21 +358,6 @@ class Organizer:
 
             pred_filepaths = self.io.get_pred_files_list(epoch, fileno)
 
-        # concatenate all prediction files if wished
-        concatenated_folder = self.io.get_subfolder("predictions") + '/concatenated'
-        n_val_files = self.io.get_no_of_files("val")
-        if concatenate is True and n_val_files > 1:
-            if not os.path.isdir(concatenated_folder):
-                print('Concatenating all prediction files to a single one.')
-                pred_filename_conc = self.io.concatenate_pred_files(concatenated_folder)
-                pred_filepaths = [pred_filename_conc]
-            else:
-                # omit directories if there are any in the concatenated folder
-                fname_conc_file_list = list(file for file in os.listdir(concatenated_folder)
-                                            if os.path.isfile(os.path.join(concatenated_folder,
-                                                                           file)))
-                pred_filepaths = [concatenated_folder + '/' + fname_conc_file_list[0]]
-
         return pred_filepaths
 
     def inference(self, epoch=None, fileno=None):
@@ -568,7 +557,7 @@ class Organizer:
 
                 try:
                     plots_folder = self.io.get_subfolder("plots", create=True)
-                    ks.utils.plot_model(
+                    tf.keras.utils.plot_model(
                         model, plots_folder + "/model_plot.png", show_shapes=True)
                 except (ImportError, AttributeError) as e:
                     # TODO remove AttributeError once https://github.com/tensorflow/tensorflow/issues/38988 is fixed
@@ -589,7 +578,7 @@ class Organizer:
     def _load_model(self, filepath):
         """ Load from path, with custom objects and parallized. """
         with self.get_strategy().scope():
-            model = ks.models.load_model(
+            model = tf.keras.models.load_model(
                 filepath, custom_objects=self.cfg.get_custom_objects())
         return model
 
@@ -609,7 +598,7 @@ class Organizer:
                              "list file with pathes to h5 files first.")
 
         if self.cfg.label_modifier is None:
-            self._auto_label_modifier = get_auto_label_modifier(model)
+            self._auto_label_modifier = lib.label_modifiers.ColumnLabels(model)
 
         if self.cfg.zero_center_folder is not None:
             self.get_xs_mean(logging)
@@ -682,9 +671,9 @@ class Configuration(object):
         functions to be considered by keras during deserialization of models.
     dataset_modifier : function or None
         For orga.predict: Function that determines which datasets get created
-        in the resulting h5 file. If none, every output layer will get one
-        dataset each for both the label and the prediction, and one dataset
-        containing the y_values from the validation files.
+        in the resulting h5 file. Default: save as array, i.e. every output layer
+        will get one dataset each for both the label and the prediction,
+        and one dataset containing the y_values from the validation files.
     fixed_batchsize : bool
         The last batch in the file might be smaller then the batchsize.
         Usually, this is no problem, but set to True to skip this batch
@@ -760,34 +749,30 @@ class Configuration(object):
     # TODO add a clober script that properly deletes models + logfiles
     def __init__(self, output_folder, list_file=None, config_file=None, **kwargs):
         self.batchsize = 64
-        self.learning_rate = None
-
-        self.zero_center_folder = None
-        self.validate_interval = None
-        self.cleanup_models = False
+        self.callback_train = []
         self.class_weight = None
-
-        self.sample_modifier = None
+        self.cleanup_models = False
+        self.custom_objects = {}
         self.dataset_modifier = None
-        self.label_modifier = None
-
+        self.fixed_batchsize = False
         self.key_x_values = "x"
         self.key_y_values = "y"
-        self.custom_objects = {}
-        self.shuffle_train = False
-
-        self.fixed_batchsize = False
-        self.callback_train = []
-        self.use_scratch_ssd = False
-        self.verbose_train = 1
-        self.verbose_val = 0
+        self.label_modifier = None
+        self.learning_rate = None
         self.make_weight_plots = False  # Removed in v0.11.1
-        self.n_events = None
         self.max_queue_size = 10
+        self.multi_gpu = True
+        self.n_events = None
+        self.sample_modifier = None
+        self.shuffle_train = False
         self.train_logger_display = 100
         self.train_logger_flush = -1
-        self.multi_gpu = True
+        self.use_scratch_ssd = False
+        self.validate_interval = None
+        self.verbose_train = 1
+        self.verbose_val = 0
         self.y_field_names = None
+        self.zero_center_folder = None
 
         self._default_values = dict(self.__dict__)
 
@@ -865,8 +850,14 @@ class Configuration(object):
         for key, value in user_values.items():
             if hasattr(self, key):
                 if key == "sample_modifier":
-                    value = from_register(
-                        toml_entry=value, register=sample_modifiers.smods)
+                    value = orcanet.misc.from_register(
+                        toml_entry=value, register=lib.sample_modifiers.smods)
+                elif key == "dataset_modifier":
+                    value = orcanet.misc.from_register(
+                        toml_entry=value, register=lib.dataset_modifiers.dmods)
+                elif key == "label_modifier":
+                    value = orcanet.misc.from_register(
+                        toml_entry=value, register=lib.label_modifiers.lmods)
                 setattr(self, key, value)
             else:
                 raise AttributeError(f"Unknown attribute {key} in config file")
@@ -909,7 +900,7 @@ class Configuration(object):
     def get_custom_objects(self):
         """ Get user custom objects + orcanet internal ones. """
         orcanet_co = medgeconv.custom_objects
-        orcanet_loss_functions = orcanet.utilities.losses.loss_functions
+        orcanet_loss_functions = lib.losses.loss_functions
         return {**orcanet_co, **orcanet_loss_functions, **self.custom_objects}
 
 
